-- name=int_button_visor
--******************************************************************************************
function public.Init ( pos_z )

  ObjAttach( "int_button_visor", interface.originhub );
  ObjSet( "int_button_visor", { pos_z = pos_z } );

  MsgSubscribe( Command_Interface_UpdateTextures, private.WideScreenUpdate );

  private.SHOW_ANIM_TIME = 0.3;
  private.MOUSE_OVER_ANIM_TIME = 0.3;

  public.POSITION = 790;

  private.ANIM_POSITION = -1152;

  private.show = false;
  private.panel_show = false;

  private.WideScreenUpdate();

  private.event_list = 
  {
    ["arcticstation"] = { start_event = "clk_visor",         end_event = "clk_switch",                room = "arcticstation",   level = 1 },
    ["stationhall"] =   { start_event = "vid_stationhall_shadeindanger",   end_event = "clk_ventil",                room = "stationhall",     level = 1 },
    ["laboratory"] =    { start_event = "vid_laboratory_selfdestruction",     end_event = "use_crimpingpliers",        room = "laboratory",      level = 1 },
    ["port"] =    { start_event = "opn_port",    end_event = "get_backpack",       room = "port",      level = 2 },
    ["town"] =    { start_event = "opn_town",    end_event = "use_husky_2",       room = "town",      level = 2 },
    ["centralhall"] =    { start_event = "vid_centralhall_teleport",    end_event = "vid_centralhall_chase",       room = "centralhall",      level = 2 },
    ["eskimosettlement"] =    { start_event = "vid_eskimosettlement_danger",    end_event = "use_rope_2",       room = "eskimosettlement",      level = 2 },
    ["stalkersresidence"] =    { start_event = "vid_stalkersresidence_division",    end_event = "win_lattice",       room = "stalkersresidence",      level = 3 }
  }

  ObjSet( "obj_int_button_visor_close", { alp = 0 } );

  --
  -- запуск визора
  --
  ObjSet( "obj_int_button_visor_clk", {  event_mdown = public.MouseDownShow });
  ObjSet( "obj_int_button_visor_clk_show", { event_mdown = public.MouseDownShow });
  --
  -- скрытие сообщения
  --
  ObjSet( "obj_int_button_visor_exit", { event_mdown = public.MouseDownNotShow });

end;
--******************************************************************************************
function public.Destroy()

  MsgUnsubscribe( Command_Interface_UpdateTextures, private.WideScreenUpdate );

end;

--******************************************************************************************
function private.WideScreenUpdate ()

  if ( not GetWideScreen() ) then
    ObjSet( "int_button_visor", { pos_x = public.POSITION } );
    ObjSet( "obj_int_button_visor_ease_in_text", { pos_x = 140 } );
  else
    ObjSet( "int_button_visor", { pos_x = public.POSITION + 171 } );
    ObjSet( "obj_int_button_visor_ease_in_text", { pos_x = 0 } );
  end;

end;
--******************************************************************************************
function private.Logic()

  local current_room = GetCurrentRoom();
  local name = common.GetObjectName( current_room );
  local chapter         = ng_global.progress[ ng_global.currentprogress ].common.chapter;
  local current_lvl     = tonumber( string.sub( chapter, -1 ) );

  local cur_list = private.event_list[ name ];

  if ( not cur_list ) then

    return false;

  end;

  if ( cmn.IsEventDone( cur_list.end_event ) ) or ( cur_list.level < current_lvl ) or not cmn.IsEventDone( cur_list.start_event )  then

    return false;

  end;

  if ( cur_list.room ~= name  ) then

    return false;

  end;

  

  return true;

end;
--******************************************************************************************
function public.CheckVisorActive()

  local current_room = GetCurrentRoom();
  local name = common.GetObjectName( current_room );

  local cur_list = private.event_list[ name ];

  if cmn.IsEventDone( cur_list.start_event ) and not cmn.IsEventDone( "clk_visor_"..name )
     and not ng_global.progress[ "std" ][ "opn_"..name ].visor then

    ObjSet( "spr_int_button_visor", { alp = 1 } );
    ObjSet( "anm_int_button_visor", { active = true, playing = true, alp = 1 } );

  else

    ObjSet( "spr_int_button_visor", { alp = 0 } );
    ObjSet( "anm_int_button_visor", { active = false, playing = false, alp = 0 } );

  end;

end;
--******************************************************************************************
function public.MouseDown()

  local active = false;

  if ( private.Logic() )then
    active = true;
  else 
    active = false;
  end;

  if not int_visor.show then 

    if ( active ) then

      --common_impl.Tutorial_Click( 'empty' );

      int_visor.Show( active );
      
      ObjMultiSet({ 
        { "obj_int_button_visor_close", { alp = 1 }},
        { "spr_int_button_visor", { alp = 0 }},
        { "anm_int_button_visor", { active = false, playing = false, alp = 0 }}
      });

    else 
      
      public.AnimShowPanel ( false );

    end;

  else 

    int_visor.Hide( active );

    ObjMultiSet({ 
      { "obj_int_button_visor_close", { alp = 0 }},
    });

  end;

end;
--******************************************************************************************
function public.Show( no_anim )

  if not private.event_list[ name ] then

    --vizor
    ObjSet( "anm_int_button_visor", { active = false, playing = false , alp = 0 });
    ObjSet( "obj_int_button_visor_close", { alp = 0 });
    ObjSet( "spr_int_button_visor", { alp = 0 });

  end;

  if ( private.show ) then

    return;

  end;

  local current_room = GetCurrentRoom();
  local name = common.GetObjectName( current_room );


  local func_after = function () 

    private.show = true;
    ObjSet( "obj_int_button_visor", { active = true, input = true, alp = 1 } );

  end;

  if no_anim == 0 then

    func_after();
    return;

  end;

  local tme = private.SHOW_ANIM_TIME;
  ObjSet( "obj_int_button_visor", { active = true } );
  ObjAnimate( "obj_int_button_visor", "alp", 0, 0, func_after,
  {
    0.0, 2, 0,
    tme, 2, 1
  } );

end;
--******************************************************************************************
function public.Hide ()

  local trg = function () 

    private.show = false;
    ObjSet( "obj_int_button_visor", { input = false, active = false } );

  end;

  local tme = private.SHOW_ANIM_TIME;
  ObjAnimate( "obj_int_button_visor", "alp", 0, 0, trg,
  {
    0.0, 3, 1,
    tme, 3, 0
  } );

end;
--******************************************************************************************
function public.MouseDownShow()

  if int_deploy_inv.IsOnScreen() then

    common_impl.HideDeployInv();    

  end;

  local active = false;

  if ( private.Logic() )then
    active = true;
  else 
    active = false;
  end;

  ObjSet("obj_int_button_visor_clk", { input = false });
  ObjSet("obj_int_button_visor_ease_in", { input = false }); 

  if ( private.panel_show and active ) then

    private.AnimHidePanel( true );

  elseif( private.panel_show and not active ) then

    private.AnimHidePanel( false );

  else 

    public.MouseDown();

  end;

  common_impl.StopAudio( "sfx", "common/audio/aud_global_task_print", 0 );

end;
--******************************************************************************************
function public.MouseDownNotShow()

  private.AnimHidePanel( false );

end;
--******************************************************************************************
function private.Update()

  ObjSet( "txt_int_button_visor_description_1", { text = "", alp = 0 } );
  ObjSet( "txt_int_button_visor_description_2", { text = "", alp = 0 } );
  ObjSet( "txt_int_button_visor_description_3", { text = "", alp = 0 } );

end;
--******************************************************************************************
--function --*** Animations ***-- () end
--******************************************************************************************
--******************************************************************************************
function private.ShowText()
  
  ObjSet( "obj_int_button_visor_clk_show", { input = true } );
  ObjSet( "obj_int_button_visor_exit", { input = true } );

  private.panel_show = true;

  local room = common.GetObjectName( common.GetCurrentRoom() ); 

end;
--******************************************************************************************
function private.AnimHidePanel( flag )

  local func_after = function ()
  
    ObjSet( "obj_int_button_visor_clk_show", { input = false } );
    ObjSet( "obj_int_button_visor_exit", { input = false } );
   
    private.panel_show = false;
    common_impl.Lock( false );

    if ( flag ) then

      public.MouseDown();

    else 

      ObjSet( "obj_int_button_visor_clk", {  input = true });

    end;
  
  end;
 
  common_impl.Lock( true);

  common_impl.PlayAudio( "sfx", "common/audio/aud_visor_menu_hide", 0, "", 0 );

  private.Update();


  ObjAnimate( "spr_int_button_visor_panel_2", "scale_x", 0, 0, "", { 0,0,2, 0.3,0,0 } );
  ObjAnimate( "obj_int_button_visor_panel_1", "scale_x", 0, 0, func_after, { 0,0,1, 0.3,0,1, 0.8,0,0 } ); 

end;
--******************************************************************************************
function public.AnimShowPanel ( active )

  if ( private.panel_show ) then

    return;
    
  end;

  private.Update();

  local func_after = function ()

    common_impl.Lock( false );

     private.ShowText();

  end;

  common_impl.Lock( true );

  ObjSet( "spr_int_button_visor_window_close", { alp = 0 });
  ObjSet( "obj_int_button_visor_ease_in", { alp = 1, input = true } );

  if ( active ) then
    ObjSet( "anm_int_button_visor", { active = true, playing = true, alp = 1 } );
    ObjSet( "spr_int_button_visor", { alp = 1 } );
  end;

  ObjAnimate( "obj_int_button_visor_panel_1", "scale_x", 0, 0, "", { 0,0,0, 1,0,1 } );
  ObjAnimate( "spr_int_button_visor_panel_2", "scale_x", 0, 0, func_after, { 0,0,0, 1,0,0, 1.3,0,2 } );  

  common_impl.PlayAudio( "sfx", "common/audio/aud_visor_need_scan", 0, "", 0 );
  common_impl.PlayAudio( "sfx", "common/audio/aud_visor_menu_show", 0, "", 0 );

  for i = 1, 3 do

    ObjSet( "txt_int_button_visor_description_"..i, { text =  "str_int_button_visor_description_"..i } );

  end; 

  if not active then

    ObjSet( "txt_int_button_visor_description_3", { text =  "str_int_button_visor_not_description_3" } );

  end;

  ObjAnimate( "txt_int_button_visor_description_1", "alp", 0, 0, "", { 0,0,0, 0.5,0,0, 0.8,0,1 } );
  ObjAnimate( "txt_int_button_visor_description_2", "alp", 0, 0, "", { 0,0,0, 1.1,0,0, 1.3,0,1 } );
  ObjAnimate( "txt_int_button_visor_description_3", "alp", 0, 0, "", { 0,0,0, 1.1,0,0, 1.3,0,1 } );

end;
