-- name=int_diary
--******************************************************************************************
function public.Init ( pos_z )

  ObjAttach( "int_diary", interface.originhub );
  ObjSet( "int_diary", { pos_z = pos_z } );

  public.show = 0;
  private.SHOW_ANIM_TIME = 0.3;
  private.MOUSE_OVER_ANIM_TIME = 0.3;

  private.page_count = 10;
  private.current_page = 1;
  -----------------------------------------------------------------------------------

  local table_multiset = {}; 

  table.insert( table_multiset, 
                {
                  "obj_diary_close", 
                  { 
                    event_mdown = function () common_impl.PlayAudio( "sfx", "common/audio/aud_turn_page", 0, "", 0 ); private.HideAnim('hide');  end,
                    event_menter = function () private.MouseEnterAnim("button_close_focus") end,
                    event_mleave = function () private.MouseLeaveAnim("button_close_focus"); end
                  }
                }
  ); 

 
  table.insert( table_multiset, 
                {
                  "obj_diary_add_arrow_right", 
                  {
                    event_mdown = function () private.DiaryPageDown( "right" ); end,
                    event_menter = function () private.MouseEnterAnim("arrow_right") end,
                    event_mleave = function () private.MouseLeaveAnim("arrow_right"); end
                  }
                }
  );
  table.insert( table_multiset, 
                {
                  "obj_diary_add_arrow_left", 
                  {
                    event_mdown = function ()private.DiaryPageDown( "left" ); end,
                    event_menter = function () private.MouseEnterAnim("arrow_left") end,
                    event_mleave = function () private.MouseLeaveAnim("arrow_left"); end
                  }
                }
  );

  ObjMultiSet( table_multiset );

  private.PlayAnims();

end;
--******************************************************************************************
function public.Destroy()

end;
--******************************************************************************************
function private.AnimEnd( event_id )
 
  common_impl.Lock(false);

  if ( event_id == "show" ) then
  
    public.show = 1;
    ObjSet( "obj_int_diary", { input = true } );

  elseif ( event_id == "hide" ) then
  
    public.show = 0;
    ObjSet( "obj_int_diary", { active = false, visible = false, input = false } );

  end;

end;
--******************************************************************************************
function private.ShowAnim( event_id )

  local trg = function () private.AnimEnd( event_id ); end;
  local tme = private.SHOW_ANIM_TIME;

  private.InitState();
 
  common_impl.Lock(true);

  ObjAnimate( "obj_int_diary", "alp", 0, 0, trg,
  {
    0.0, 3, 0,
    tme, 3, 1
  } );

end;
--******************************************************************************************
function private.HideAnim( event_id )

  local trg = function () private.AnimEnd( event_id ); end;
  local tme = private.SHOW_ANIM_TIME;
  common_impl.Lock(true);
  ObjAnimate( "obj_int_diary", "alp", 0, 0, trg,
  {
    0.0, 3, 1,
    tme, 3, 0
  } );

end;
--******************************************************************************************
function private.MouseEnterAnim( but_name )

  SetCursor( CURSOR_HAND );

  common_impl.PlayAudio( "sfx", "common/audio/aud_guidance", 0, "", 0 );

  local obj = "spr_diary_"..but_name;
  local alp = ObjGet( obj ).alp;
  ObjAnimate( obj, "alp", 0, 0, "", { 0, 0, alp, ( common_impl.animtime * ( 1 - alp ) ), 0, 1 } );

end;
--******************************************************************************************
function private.MouseLeaveAnim( but_name )

  SetCursor( CURSOR_DEFAULT );

  local obj = "spr_diary_"..but_name;
  local alp = ObjGet( obj ).alp;
  ObjAnimate( obj, "alp", 0, 0, "", { 0, 0, alp, ( common_impl.animtime * alp ), 0, 0 } );

end;
--******************************************************************************************
function private.InitState()

   local prg = ng_global.currentprogress;

   if prg == "ext" and ng_global.progress[ prg ].common.diary.current < 14 then

     ng_global.progress[ prg ].common.diary.current = 14;

   end;

   if prg == "ext" and ng_global.progress[ prg ].common.diary.last_page < 14 then

     ng_global.progress[ prg ].common.diary.last_page = 14;

   end;

   local current = ng_global.progress[ prg ].common.diary.current;
   local number  = ng_global.progress[ prg ].common.diary.last_page;


   for i = 1, number do
        
       ObjMultiSet( {  { "spr_diary_page_event_"..i,    { alp = 1, visible = true } },
                       { "txt_diary_page_event_"..i,    { alp = 1, visible = true } },
 
                       } );


   end;
   
   if current ~= 0 then
     
     local sub = -1;
     
     if ( current > 18 ) then
       
       sub = -2;
       
     end;
   
     private.current_page = string.sub( ObjGet( ObjGetRelations( "spr_diary_page_event_"..current ).parent ).name, sub );
       
   end;
   
   for i = 1, private.page_count do
     
     ObjSet( "obj_diary_page_"..i, { visible = false } );
     
   end;
   
   ObjSet( "obj_diary_page_"..private.current_page, { visible = true, alp = 1 } );
   
   if prg == "std" then
   
     ObjSet( "txt_diary_page_number", { text = private.current_page } );
     
   else
     
     ObjSet( "txt_diary_page_number", { text = private.current_page - 7 } );
     
   end;
   
   private.ButtonActive();

end;
--******************************************************************************************
function private.DiaryPageDown( course )

  local func_after = function ()

    local prg = ng_global.currentprogress;
  
    ObjSet( "obj_diary_page_"..( private.current_page ), { alp = 0, visible = true } );

    if course == "left" then
      private.current_page = math.floor(private.current_page - 1);
    else
      private.current_page = math.floor(private.current_page + 1);
    end;
    
    common_impl.Lock(false);
    
    DbgTrace("private.DiaryPageDown:"..tostring(private.current_page));

    private.ButtonActive();
    
    local prg = ng_global.currentprogress;
    
    if prg == "std" then
   
     ObjSet( "txt_diary_page_number", { text = private.current_page } );
     
    else
     
     ObjSet( "txt_diary_page_number", { text = private.current_page - 7 } );
     
    end;
 
  end;

  local def = 0;
  if course == "left" then
    def = -1;
  else
    def = 1;
  end;

  common_impl.Lock( true );

  local prg = ng_global.currentprogress;
  
  local rand = math.random( 1, 3 );

  common_impl.PlayAudio( "sfx", "common/audio/aud_turn_page_"..rand, 0, "", 0 );

  ObjAnimate( "obj_diary_page_"..private.current_page, "alp", 0, 0, "", 
  { 
    0.0, 0, 1, 
    0.1, 0, 0, 
  } );

  ObjSet( "obj_diary_page_"..( math.floor(private.current_page + def) ), { alp = 0, visible = true } );

  ObjAnimate( "obj_diary_page_"..( math.floor(private.current_page + def) ), "alp", 0, 0, func_after, 
  { 
    0.0, 0, 0, 
    0.1, 0, 1 
  } );

end;
--******************************************************************************************
function private.ButtonActive()

  local prg = ng_global.currentprogress;
  local right_index = ng_global.progress[ prg ].common.diary.last_page;
  local left_index = 1; 
  
  if right_index ~= 0 then
    
    local sub = -1;
     
    if ( right_index > 18 ) then
       
      sub = -2;
       
    end;
    
    right_index = tonumber( string.sub( ObjGet( ObjGetRelations( "spr_diary_page_event_"..right_index ).parent ).name, sub ) );
    
  end;

  if prg == "ext" then

    left_index = 8;

  end;

  if ng_global.progress[ prg ].common.diary.current ~= "" then

    local num = tonumber( private.current_page );

    if num < tonumber( right_index ) then
      ObjSet( "obj_diary_add_arrow_right", { input = true } );
    else
      ObjSet( "obj_diary_add_arrow_right", { input = false } );
    end;
    
    if num > tonumber( left_index ) then
      ObjSet( "obj_diary_add_arrow_left", { input = true } );
    else
      ObjSet( "obj_diary_add_arrow_left", { input = false } );
    end;    
  end; 

end;
--******************************************************************************************
function public.Show()

  local event_id = "show";
  
  ObjSet( "obj_int_diary", { active = true, visible = true, alp = 0 } );
  common_impl.HideDeployInv();
  private.ShowAnim( event_id );

end;
--******************************************************************************************
function public.Hide()

  local event_id = "hide";
  private.HideAnim( event_id );

end;
--******************************************************************************************
function private.PlayAnims()

  ObjAnimate( "spr_diary_light_1", "alp", 1, 0, "", { 0,0,0.3, 1.5,0,1, 3.0,0,0.3 } );
  ObjAnimate( "spr_diary_light_2", "alp", 1, 0, "", { 0,0,0.6, 2.0,0,1, 4.0,0,0.6 } );

end;