-- name=int_puzzlehelp
function public.Init ( pos_z )

  private.GRID_CORNER_W =  88;
  private.GRID_CORNER_H =  88;
  private.GRID_MID_W    =   8;
  private.GRID_MID_H    =   8;

  private.GRID_BORDER_W = 100;
  private.GRID_BORDER_H = 100;

  private.MIN_W = 490;
  private.MAX_W = 490;
  private.MIN_H = 210;
  private.MAX_H = 500;

  private.RELOAD_TIME =  15.0;

  private.BUTTON_MOUSE_OVER_ANIM_TIME = 0.3;
  private.SHOW_ANIM_TIME = 0.3;

  ObjSet("obj_int_puzzlehelp_button_skip", {
    event_mdown = private.MouseDown,
    event_menter = function() private.MouseEnterAnim( "skip" ) end,
    event_mleave = function() private.MouseLeaveAnim( "skip" ) end
  });

  ObjSet("obj_int_puzzlehelp_button_close", {
    event_mdown = public.Hide,
    event_menter = function() private.MouseEnterAnim( "close" ) end,
    event_mleave = function() private.MouseLeaveAnim( "close" ) end
  });

  ObjSet("obj_int_puzzlehelp_back", {
    event_mdown = public.Hide
  });

  ObjAttach( "int_puzzlehelp", interface.originhub );
  ObjSet( "int_puzzlehelp", { pos_z = pos_z } );


end;
--******************************************************************************************
function public.Show( text, panel_pos_x, panel_pos_y )

  interface.AddIntToList( "int_puzzlehelp" );

  local panel_pos_x = panel_pos_x or 512;
  local panel_pos_y = panel_pos_y or 384;

  ObjSet( "txt_int_puzzlehelp_panel", { text = text } );

  local off_x = private.GRID_BORDER_W;
  local off_y = private.GRID_BORDER_H;

  local panel_w = ObjGet( "txt_int_puzzlehelp_panel" ).draw_width + off_x;

  if ( panel_w < private.MIN_W ) then

    panel_w = private.MIN_W;

  end;

  if ( panel_w > private.MAX_W ) then

    panel_w = private.MAX_W;

  end;

  local panel_h = ObjGet( "txt_int_puzzlehelp_panel" ).draw_height + off_y;

  if ( panel_h < private.MIN_H ) then

    panel_h = private.MIN_H;

  end;

  if ( panel_h > private.MAX_H ) then
  
    panel_h = private.MAX_H;

  end;

  local grid_corner_w = private.GRID_CORNER_W;
  local grid_corner_h = private.GRID_CORNER_H;

  local grid_mid_w = private.GRID_MID_W;
  local grid_mid_h = private.GRID_MID_H;

  interface.FrameGridSet( "int_puzzlehelp_panel",
  {
    grid_w   = panel_w,
    grid_h   = panel_h,
    corner_w = grid_corner_w,
    corner_h = grid_corner_h,
    mid_w    = grid_mid_w,
    mid_h    = grid_mid_h
  } );

  local min_grid_h = 2 * ( grid_corner_h ) + grid_mid_h;

  local pos_y = 108;
  if ( panel_h > min_grid_h ) then
    
    pos_y = ( panel_h - min_grid_h )/2 + pos_y;
    

  end;
  
  ObjMultiSet({
 
  { "int_puzzlehelp", { pos_x = panel_pos_x, pos_y = panel_pos_y } },  
  { "obj_int_puzzlehelp_button_close", { pos_y = pos_y } },  
  { "obj_int_puzzlehelp", { input = true, visible = true, active = true  } },
  });


  local trg = function () end;
  local tme = private.SHOW_ANIM_TIME;

  ObjAnimate( "obj_int_puzzlehelp", "alp", 0, 0, trg,
  {
    0.0, 3, 0,
    tme, 3, 1
  } );
  
  if ( ( ng_global.gamemode == 2 ) or ( ng_global.gamemode == 3 and not ng_global.gamemode_custom[ "skip" ] ) ) then

    ObjSet( "obj_int_puzzlehelp_button_skip", { visible = false, input = false } );

  else 

    ObjSet( "obj_int_puzzlehelp_button_skip", { visible = true, input = true } );
    private.ReloadAnim();

  end;

end;
--******************************************************************************************
function public.Hide()

  interface.RemoveIntFromList();

  local trg = function () ObjSet( "obj_int_puzzlehelp", { input = false, visible = false, active = false  } ); end;
  local tme = private.SHOW_ANIM_TIME;

  ObjAnimate( "obj_int_puzzlehelp", "alp", 0, 0, trg,
  {
    0.0, 3, 1,
    tme, 3, 0
  } );

end;
--******************************************************************************************
function public.GetTimeFull ()

  return private.RELOAD_TIME;

end;
--******************************************************************************************
function public.GetTimeRemain ()

  if ( ObjGet( "tmr_int_puzzlehelp_reload" ) ) then
    return ObjGet( "tmr_int_puzzlehelp_reload" ).time;
  else 
    return 0;
  end;

end;
--******************************************************************************************
function public.Reload ( time_remain )  
  
  ObjSet( "tmr_int_puzzlehelp_reload", 
  { 
    playing = true, time = private.RELOAD_TIME * time_remain
  } );
  private.ReloadAnim();

end;
--******************************************************************************************
function private.ReloadAnim ()

  local time_full = private.RELOAD_TIME;
  local time_remain = public.GetTimeRemain() / time_full;
  local time_min = 0.03;
  
  ObjStopAnimate( "spr_int_puzzlehelp_skip_load_right", "ang" );
  ObjStopAnimate( "spr_int_puzzlehelp_skip_load_left", "ang" );
  
  if ( time_remain > 0.5 and time_remain <= 1.0 ) then

    local current_ang = 3.14 * ( time_remain - 0.5 ) * 2;
    ObjSet( "spr_int_puzzlehelp_skip_load_left", { ang = current_ang } );
    ObjSet( "spr_int_puzzlehelp_skip_load_right", { ang = 3.14 } );
    ObjSet( "tmr_int_puzzlehelp_reload_anim", { playing = true, time = time_min, endtrig = private.ReloadAnim } );
    ObjSet( "spr_int_puzzlehelp_button_skip_active", { alp = 0 } );

  elseif ( time_remain > 0.0 and  time_remain < 0.5 ) then
    
    local current_ang = 3.14 * time_remain * 2;
    ObjSet( "spr_int_puzzlehelp_skip_load_left", { ang = 0 } );
    ObjSet( "spr_int_puzzlehelp_skip_load_right", { ang = current_ang } );
    ObjSet( "tmr_int_puzzlehelp_reload_anim", { playing = true, time = time_min, endtrig = private.ReloadAnim } );
    ObjSet( "spr_int_puzzlehelp_button_skip_active", { alp = 0 } );

  else

    ObjSet( "spr_int_puzzlehelp_skip_load_right", { ang = 0 } );
    ObjSet( "spr_int_puzzlehelp_skip_load_left", { ang = 0 } );
    ObjSet( "spr_int_puzzlehelp_button_skip_active", { alp = 1 } );

  end;
  
end;
--******************************************************************************************
function private.MouseDown ()

  local room_current = GetCurrentRoom();
  
  if ( string.find( room_current, "mg_superpuzzle" ) ) then

    if ( public.GetTimeRemain() == 0 ) then

      local name = string.sub( room_current, 4, string.len( room_current ) );
      local puzzle_num = ng_global.progress[ ng_global.currentprogress ][ "win_"..name ].puzzle_num;
      _G[ room_current ][ "SkipPuzzle"..puzzle_num ]();
      ng_global.progress[ ng_global.currentprogress ][ "win_"..name ].skippuzzle_clk = true;
      common_impl.PlayAudio( "sfx", "common/audio/level1/aud_mg_superpuzzle_1_skip_part", 0, "", 0 );
      
    else 
      interface.DialogShow( "hnt_not_ready", 512, 384 );
    end;

  end;

end;
--******************************************************************************************
function private.MouseEnterAnim ( name )

  SetCursor( CURSOR_HAND );

  local obj = "spr_int_puzzlehelp_"..name.."_focus";
  local alp = ObjGet( obj ).alp;
  local tme = ( 1 - alp ) * private.BUTTON_MOUSE_OVER_ANIM_TIME;

  ObjAnimate( obj, "alp", 0, 0, "",
  {
    0.0, 2, alp,
    tme, 2, 1
  } );

  if ( GetPerformanceMode() == 0 ) then

    obj = "anm_int_puzzlehelp_"..name.."_focus";
    ObjAnimate( obj, "alp", 0, 0, "",
    {
      0.0, 2, alp,
      tme, 2, 1
    } );

  end;

end;
--******************************************************************************************
function private.MouseLeaveAnim ( name )

  SetCursor( CURSOR_DEFAULT );

  local obj = "spr_int_puzzlehelp_"..name.."_focus";
  local alp = ObjGet( obj ).alp;
  local tme = alp * private.BUTTON_MOUSE_OVER_ANIM_TIME;

  ObjAnimate( obj, "alp", 0, 0, "",
  {
    0.0, 1, alp,
    tme, 1, 0
  } );

  if ( GetPerformanceMode() == 0 ) then

    obj = "anm_int_puzzlehelp_"..name.."_focus";
    ObjAnimate( obj, "alp", 0, 0, "",
    {
      0.0, 1, alp,
      tme, 1, 0
    } );

  end;


end;
--******************************************************************************************
