-- name=int_taskpanel_impl
--******************************************************************************************
function public.Init ()

  public.DIRECTION = 0;

  private.TASK_COLOR_R = 1;
  private.TASK_COLOR_G = 1;
  private.TASK_COLOR_B = 1;

  private.TASK_MARKED_COLOR_R = 0.7804;
  private.TASK_MARKED_COLOR_G = 0.60392;
  private.TASK_MARKED_COLOR_B = 0.42352;

  private.TASK_COMPLETED_COLOR_R = 0.02745;
  private.TASK_COMPLETED_COLOR_G = 0.09019;
  private.TASK_COMPLETED_COLOR_B = 0.10588;

  private.MOVE_ANIM_TIME      = 0.6;
  private.MOVE_ANIM_POS_Y_TOP = 709;
  private.MOVE_ANIM_POS_Y_BOT = 779;

  public.sound_play = true;
  public.sound_clk_play = true;

end;
--******************************************************************************************
function public.ShowAnim( event_id )

  local trg = function () int_taskpanel.EventAnimEnd( event_id ); end;

  local tme = private.MOVE_ANIM_TIME;

  ObjAnimate( "int_taskpanel_impl", "pos_y", 0, 0, trg,
  {
    0.0, 2, private.MOVE_ANIM_POS_Y_BOT,
    tme, 2, private.MOVE_ANIM_POS_Y_TOP
  } );

end;
--******************************************************************************************
function public.HideAnim( event_id )

  local trg = function () int_taskpanel.EventAnimEnd( event_id ); end;

  local tme = private.MOVE_ANIM_TIME;

  ObjAnimate( "int_taskpanel_impl", "pos_y", 0, 0, trg,
  {
    0.0, 1, private.MOVE_ANIM_POS_Y_TOP,
    tme, 1, private.MOVE_ANIM_POS_Y_BOT
  } );

end;
--******************************************************************************************
function public.CompleteTaskAnim( object_name, task_id, tsk_count, event_id, no_anim )

  if no_anim then
    int_taskpanel.EventAnimEnd( event_id );
  else
    local trg = function () int_taskpanel.EventAnimEnd( event_id ); end;

    --ObjAnimate( object_name, "scale_xy", 0, 0, trg,
    --{
    --  0.0, 3, 1, 1,
    --  0.3, 3, 2, 2,
    --  0.9, 3, 0, 0
    --} );

    local sound_number = math.random( 1,3);

    if public.sound_clk_play ~= false then

      common_impl.PlayAudio( "sfx", "common/audio/aud_hoclk"..sound_number.."_sfx", 0, "", 0 );

    end;

    if public.sound_play ~= false then

      common_impl.PlayAudio( "sfx", "common/audio/aud_hide_sfx", 0, "", 0 );
  
    end;

    local collect_pos = GetObjPosByObj( object_name, InterfaceWidget_Top_Name );
    --collect_pos[1] = collect_pos[1]*ObjGet("ng_interface_internal").scale_x;
    --collect_pos[2] = collect_pos[2]*ObjGet("ng_interface_internal").scale_y;
    
    local collect_drawoff_x = ObjGet( object_name ).drawoff_x;
    local collect_drawoff_y = ObjGet( object_name ).drawoff_y;
    
    local collect_name  = "pfx_int_taskpanel_collect_"..object_name;

    ObjAttach( object_name, InterfaceWidget_Top_Name );
    ObjSet( object_name ,{ pos_x = collect_pos[1], pos_y = collect_pos[2] });
    
    ObjCreate( collect_name, "partsys" );
    
    ObjSet( collect_name,
    {
      res = "assets/interface/resources/effects_ho",
      pos_x = collect_drawoff_x, pos_y = collect_drawoff_y,
      active = 1, visible = 1, input = 0, pos_z = 10
    } );

    ObjAttach( collect_name, InterfaceWidget_Top_Name );
    ObjSet(collect_name, {blendmode = 2});
    
    PartSysSetMaskObj( collect_name, object_name );  
    ObjAnimate( object_name, "alp",0,0, trg,
    { 
        0.0, 0, 1,
        0.5, 0, 1,
        1.0, 0, 0
    } );

    ObjAnimate( "spr_int_taskpanel_task_"..task_id, "alp",0,0, "", 
    {
        0.0, 2, 0,
        0.7, 2, 1,
        1.0, 2, 0
    });  

  end;

  
end;
--******************************************************************************************
function public.SetTask( task_id, task_params )

  local task_color_r = private.TASK_COLOR_R;
  local task_color_g = private.TASK_COLOR_G;
  local task_color_b = private.TASK_COLOR_B;

  if ( task_params.count < 1 ) then

    task_color_r = private.TASK_COMPLETED_COLOR_R;
    task_color_g = private.TASK_COMPLETED_COLOR_G;
    task_color_b = private.TASK_COMPLETED_COLOR_B;    

  end;

  if ( task_params.marked == 1 ) then

    task_color_r = private.TASK_MARKED_COLOR_R;
    task_color_g = private.TASK_MARKED_COLOR_G;
    task_color_b = private.TASK_MARKED_COLOR_B;

  end;

  local task_pattern = "str_int_taskpanel_pattern";

  if ( task_params.count > 1 ) then

    task_pattern = "str_int_taskpanel_pattern_multiple";

  end;

  if ng_global.progress[ ng_global.currentprogress ].common.chapter == "levelscr" then

    task_params.name = string.gsub( task_params.name, "_scr_", "_" );

  end;

  ObjSet( "txt_int_taskpanel_task_"..task_id,
  {
    text   = task_pattern,
    param0 = task_color_r,
    param1 = task_color_g,
    param2 = task_color_b,
    param3 = StringGet( task_params.name ),
    param4 = task_params.count
  } );

end;
--******************************************************************************************
function public.UnmarkTaskAnim( task_id, event_id )

  local task_color_r = private.TASK_COLOR_R;
  local task_color_g = private.TASK_COLOR_G;
  local task_color_b = private.TASK_COLOR_B;

  ObjSet( "txt_int_taskpanel_task_"..task_id,
  {
    param0 = task_color_r,
    param1 = task_color_g,
    param2 = task_color_b,
  } );

end;
--******************************************************************************************
function public.MarkTaskAnim( task_id, event_id )

  local task_color_r = private.TASK_MARKED_COLOR_R;
  local task_color_g = private.TASK_MARKED_COLOR_G;
  local task_color_b = private.TASK_MARKED_COLOR_B;

  ObjSet( "txt_int_taskpanel_task_"..task_id,
  {
    param0 = task_color_r,
    param1 = task_color_g,
    param2 = task_color_b,
  } );

end;
--******************************************************************************************
function public.HideTextPanel( ho_name )

  ObjSet( "obj_int_taskpanel", { visible = false } );
  ObjAttach( "obj_"..ho_name.."_taskpanel", "obj_int_taskpanel_impl" );

end;
--******************************************************************************************
function public.ShowTextPanel( ho_name )

  ObjSet( "obj_int_taskpanel", { visible = true } );
  ObjDetach( "obj_"..ho_name.."_taskpanel" );

end;
--******************************************************************************************
